/*
* Copyright 2011 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package groovyx.javafx.factory

import javafx.scene.shape.Shape

class ShapeFactory extends NodeFactory {
    private final Class<? extends Shape> shapeClass

    ShapeFactory(Class<? extends Shape> shapeClass) {
        if (shapeClass == null)
            throw new IllegalArgumentException("shapeClass cannot be null")
        this.shapeClass = shapeClass
    }

    Object newInstance(FactoryBuilderSupport builder, Object name, Object value, Map attr) {
        if (FactoryBuilderSupport.checkValueIsType(value, name, shapeClass)) {
            return value
        } else {
            return shapeClass.newInstance()
        }
    }
}
